@@ -28,7 +28,6 @@ def get_parser():
   parser.add_argument('-d', '--deploy_branch', default="deploy")
   parser.add_argument('-toc', '--table_of_contents_path', default="")
   parser.add_argument('-url', '--url_path', type=str, default="")
-  parser.add_argument('-r', '--relocate_include', action='store_true')
 
   return parser.parse_args()
 
@@ -64,10 +63,7 @@ if __name__ == "__main__":
       table_of_contents = book.table_of_contents()
       book.toc.path.write_text(table_of_contents)
 
-    if ag.relocate_include:
-      book.relocate_include(ag.test)
-    else:
-      book.include_file(ag.test)
+    book.include_file(ag.test)
   else:
     repo = Repository(
         ag.path,
@@ -77,8 +73,4 @@ if __name__ == "__main__":
         ag.deploy_branch,
         ag.user,
     )
-
-    if ag.relocate_include:
-      repo.relocate_include(ag.test)
-    else:
-      repo.include_file(ag.test)
+    repo.include_file(ag.test)
