@@ -118,7 +118,7 @@ class Markdown(File):
 
   def extract_heading(self) -> list[tuple[int, str]]:
     logging.debug("extract_markdown()")
-    text = Md(extensions=['fenced_code']).convert(self.content)
+    text = Md(extensions=['fenced_code']).convert(self.content.replace("    #", ""))
     md = BeautifulSoup(text, "html.parser")
     return [(int(str(line)[2]), str(line)[4:-5]) for line in md.find_all(re.compile('^h[1-6]$'))]
 
